@@ -74,7 +74,8 @@ def ldos__gridded__2D(energy__grid, space__profile, energy__profile, mass__grid,
                 profile = tools.adjust__energy__profile__to__wave__vector(energy__profile,mass__grid,k)
                 energy__levels = shroodinger__equation.eigenvalues_1(space__profile, profile, mass__grid, min__energy__level - energy__grid__interval , max_energy__level + energy__grid__interval, energy__interval)
                 for energy__level in energy__levels:
-                    eigenfunction = shroodinger__equation.eigenfunctions_1(space__profile, profile, mass__grid, energy__level)
+                    y_min = min(profile[2:-2])
+                    eigenfunction = shroodinger__equation.eigenfunctions_1(space__profile, profile, mass__grid, energy__level, profile.index(y_min,2,len(y_)-2)
                     eigenfunction = shroodinger__equation.normalization(eigenfunction, space__profile)
                     for l in range(0,len(energy__grid) - 1):
                         if energy__level >= energy__grid[l]:
@@ -116,7 +117,8 @@ def ldos__gridded__2D(energy__grid, space__profile, energy__profile, mass__grid,
                 profile = tools.adjust__energy__profile__to__wave__vector(energy__profile,mass__grid,k)
                 energy__levels = shroodinger__equation.eigenvalues_1(space__profile, profile, mass__grid, min__energy__level - energy__grid__interval , max_energy__level + energy__grid__interval, energy__interval)
                 for energy__level in energy__levels:
-                    eigenfunction = shroodinger__equation.eigenfunctions_1(space__profile, profile, mass__grid, energy__level)
+                    y_min = min(profile[2:-2])
+                    eigenfunction = shroodinger__equation.eigenfunctions_1(space__profile, profile, mass__grid, energy__level, profile.index(y_min,2,len(y_)-2)
                     eigenfunction = shroodinger__equation.normalization(eigenfunction, space__profile)
                     for l in range(0,len(energy__grid) - 1):
                         if energy__level >= energy__grid[l]:
@@ -135,7 +137,8 @@ def ldos__gridded__2D(energy__grid, space__profile, energy__profile, mass__grid,
                 profile = tools.adjust__energy__profile__to__wave__vector(energy__profile,mass__grid,k)
                 energy__levels = shroodinger__equation.eigenvalues_1(space__profile, profile, mass__grid, min__energy__level - energy__grid__interval , max_energy__level + energy__grid__interval, energy__interval)
                 for energy__level in energy__levels:
-                    eigenfunction = shroodinger__equation.eigenfunctions_1(space__profile, profile, mass__grid, energy__level)
+                    y_min = min(profile[2:-2])
+                    eigenfunction = shroodinger__equation.eigenfunctions_1(space__profile, profile, mass__grid, energy__level, profile.index(y_min,2,len(y_)-2)
                     eigenfunction = shroodinger__equation.normalization(eigenfunction, space__profile)
                     for i in range(0,len(energy__grid) - 1):
                         if energy__level >= energy__grid[i]:
@@ -197,7 +200,8 @@ def ldos__gridded__2D(energy__grid, space__profile, energy__profile, mass__grid,
             for profile_ in profile:
                 energy__levels = shroodinger__equation.eigenvalues_1(space__profile, profile_, mass__grid, min__energy__level - energy__grid__interval , max_energy__level + energy__grid__interval, energy__interval)
                 for energy__level in energy__levels:
-                    eigenfunction = shroodinger__equation.eigenfunctions_1(space__profile, profile_, mass__grid, energy__level)
+                    y_min = min(profile_[2:-2])
+                    eigenfunction = shroodinger__equation.eigenfunctions_1(space__profile, profile_, mass__grid, energy__level, profile_.index(y_min,2,len(y_)-2)
                     eigenfunction = shroodinger__equation.normalization(eigenfunction, space__profile)
                     for i in range(0,len(energy__grid) - 1):
                         if energy__level >= energy__grid[i]:
