@@ -1,7 +1,7 @@
 import units_QBD
 from math import sqrt
 
-def eigenvalues_1(space__grid, energy__grid, mass__grid,min__energy__level=0, max__energy__level=12e-19, level__resolution=1e-21):
+def eigenvalues_1(space__grid, energy__grid, mass__grid,min__energy__level, max__energy__level, level__resolution):
     energy__grid = [energy / units_QBD.SI_['eV'][0] for energy in energy__grid]
     mass__grid = [mass / units_QBD.SI_['m_e'][0] for mass in mass__grid]
     level__resolution_ = level__resolution / units_QBD.SI_['eV'][0]
@@ -26,8 +26,9 @@ def eigenvalues_1(space__grid, energy__grid, mass__grid,min__energy__level=0, ma
 
     eigenvalues = []
     level = 1
+    me = min(energy__grid)
     while(True):
-        E_min = min__energy__level_
+        E_min = me
         E_max = max__energy__level_
         E_ave = ...
 
@@ -52,13 +53,20 @@ def eigenvalues_1(space__grid, energy__grid, mass__grid,min__energy__level=0, ma
             if eigenvalues[-2] == eigenvalues[-1]: 
                 break
 
+
+
+    c1 = min__energy__level_ * units_QBD.SI_['eV'][0]
+    c2 = (me + level__resolution_) * units_QBD.SI_['eV'][0]
+    c3 = level__resolution_ * units_QBD.SI_['eV'][0]
     te = []
     for i in eigenvalues[:-2]:
-        if abs(i) > level__resolution_ * units_QBD.SI_['eV'][0]: 
-            te.append(i)
+        if i >= c1:
+            if i > c2:
+                if abs(i) > c3: 
+                    te.append(i)
     return te
 
-def eigenfunctions_1(space__grid, energy__grid, mass__grid, energy):
+def eigenfunctions_1(space__grid, energy__grid, mass__grid, energy, k_ii):
     energy__grid = [energy / units_QBD.SI_['eV'][0] for energy in energy__grid]
     mass__grid = [mass / units_QBD.SI_['m_e'][0] for mass in mass__grid]
     energy = energy / units_QBD.SI_['eV'][0]
@@ -90,9 +98,8 @@ def eigenfunctions_1(space__grid, energy__grid, mass__grid, energy):
         i = grid__points__count - i
         ThetaP[i] = 1 / (AZW_D[i] - energy * as2 - AZW_U[i] * AZW_U[i] * ThetaP[i + 1])
 
-
     wave__vector = [0] * grid__points__count
-    k = int(grid__points__count / 2)
+    k = k_ii # int(grid__points__count / 2)
 
     wave__vector[k] = 1
     for i in range(k + 1, grid__points__count - 1):
